==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/emr/kotlin/outputs/ClusterMasterInstanceGroupEbsConfig.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.emr.kotlin.outputs

import kotlin.Int
import kotlin.String
import kotlin.Suppress

/**
 *
 * @property iops Number of I/O operations per second (IOPS) that the volume supports.
 * @property size Volume size, in gibibytes (GiB).
 * @property throughput The throughput, in mebibyte per second (MiB/s).
 * @property type Volume type. Valid options are `gp3`, `gp2`, `io1`, `standard`, `st1` and `sc1`. See [EBS Volume Types](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html).
 * @property volumesPerInstance Number of EBS volumes with this configuration to attach to each EC2 instance in the instance group (default is 1).
 */
public data class ClusterMasterInstanceGroupEbsConfig(
    public val iops: Int? = null,
    public val size: Int,
    public val throughput: Int? = null,
    public val type: String,
    public val volumesPerInstance: Int? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.emr.outputs.ClusterMasterInstanceGroupEbsConfig):
            ClusterMasterInstanceGroupEbsConfig = ClusterMasterInstanceGroupEbsConfig(
            iops = javaType.iops().map({ args0 -> args0 }).orElse(null),
            size = javaType.size(),
            throughput = javaType.throughput().map({ args0 -> args0 }).orElse(null),
            type = javaType.type(),
            volumesPerInstance = javaType.volumesPerInstance().map({ args0 -> args0 }).orElse(null),
        )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/emr/kotlin/outputs/ClusterMasterInstanceGroupEbsConfig.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.emr.kotlin.outputs

import kotlin.Int
import kotlin.String
import kotlin.Suppress

/**
 *
 * @property iops Number of I/O operations per second (IOPS) that the volume supports.
 * @property size Volume size, in gibibytes (GiB).
 * @property throughput The throughput, in mebibyte per second (MiB/s).
 * @property type Volume type. Valid options are `gp3`, `gp2`, `io1`, `standard`, `st1` and `sc1`. See [EBS Volume Types](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html).
 * @property volumesPerInstance Number of EBS volumes with this configuration to attach to each EC2 instance in the instance group (default is 1).
 */
public data class ClusterMasterInstanceGroupEbsConfig(
    public val iops: Int? = null,
    public val size: Int,
    public val throughput: Int? = null,
    public val type: String,
    public val volumesPerInstance: Int? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.emr.outputs.ClusterMasterInstanceGroupEbsConfig): ClusterMasterInstanceGroupEbsConfig = ClusterMasterInstanceGroupEbsConfig(
            iops = javaType.iops().map({ args0 -> args0 }).orElse(null),
            size = javaType.size(),
            throughput = javaType.throughput().map({ args0 -> args0 }).orElse(null),
            type = javaType.type(),
            volumesPerInstance = javaType.volumesPerInstance().map({ args0 -> args0 }).orElse(null),
        )
    }
}
